#include <X11/Xlib.h>
#include <typeinfo.h>
#include "../include/sprite.h"
#include "../include/mfsprite.h"

void MultiframeSprite::RenderSprite(Drawable d) {
  XGCValues gcv;
  gcv.clip_x_origin = (int)x;
  gcv.clip_y_origin = (int)y - (cy * frame);
  XChangeGC(host->theDisplay(),sprgc,GCClipXOrigin | GCClipYOrigin,&gcv);
  XCopyArea(host->theDisplay(),pxm,d,sprgc,0,cy * frame,cx,cy,(int)x,(int)y);
}

void MultiframeSprite::MoveSprite(float newx,float newy) {
  Sprite::MoveSprite(newx,newy);
  if(auto_animate) {
    count++; if(count >= delay) {
      count = 0;
      frame++; frame %= maxframes;
    }
  }
}

MultiframeSprite::MultiframeSprite(SpriteAppWin *sw,float _x,float _y,char
				   **data,unsigned int mf,unsigned int d)
  : Sprite(sw,_x,_y,data) {
    maxframes = mf;
    frame = 0;
    count = 0;
    delay = d;
    CalculateSize();
    auto_animate = 0;
}
MultiframeSprite::MultiframeSprite(SpriteAppWin *sw,float _x,float _y,Pixmap
				   pm,Pixmap mask,unsigned int mf,
				   unsigned int d)
  : Sprite(sw,_x,_y,pm,mask) {
    maxframes = mf;
    frame = 0;
    count = 0;
    delay = d;
    if(pm != 0) {
      CalculateSize();
    }
    auto_animate = 0;
}

void MultiframeSprite::CalculateSize() {
  unsigned long dummy;
  int dummy2;
  XGetGeometry(host->theDisplay(),pxm,&dummy,&dummy2,&dummy2,&dummy2,
	       &cy,&dummy2,
	       &dummy2);
  cy /= maxframes;
}

void MultiframeSprite::SetMaxFrames(unsigned int m) {
  maxframes = m;
  CalculateSize();
}

void MultiframeSprite::ChangeSpriteShape(char **data) {
  Sprite::ChangeSpriteShape(data);
  CalculateSize();
}

void MultiframeSprite::ChangeSpriteShape(Pixmap pxm,Pixmap mask) {
  Sprite::ChangeSpriteShape(pxm,mask);
  CalculateSize();
}
